01. Hello World!
****************

.. figure:: images/01_hello_world.png
	:scale: 50 %
	:alt: 01_hello_world
	:align: center
	:figclass: align-center

	Hello World

.. literalinclude:: ../../examples/GLWindow/01_hello_world.py
	:linenos:
